# v0.1.0 (2024-06-14)

## New features

- `iter_subproc()` utility
- `iterable_subprocess()` utility
- `CommandError` exception

# v0.0.1rc2 (2024-05-14)

- Non-functional test release

# v0.0.1rc1 (2024-05-13)

- Non-functional test release
